GradientButtonStyleButton class abstract

The base StatefulWidget class for buttons whose style is defined by a ButtonStyle object.

Concrete subclasses must override defaultStyleOf and themeStyleOf.

See also:

Inheritance
Implementers

Constructors

GradientButtonStyleButton({Key? key, required VoidCallback? onPressed, required VoidCallback? onLongPress, required ButtonStyle? style, required FocusNode? focusNode, required bool autofocus, required Clip clipBehavior, required Widget? child, required Gradient gradient})
Create a GradientButtonStyleButton.
const

Properties

autofocus → bool
True if this widget will be selected as the initial focus when no other node in its scope is currently focused.
final
child → Widget?
Typically the button's label.
final
clipBehavior → Clip
The content will be clipped (or not) according to this option.
final
enabled → bool
Whether the button is enabled or disabled.
no setter
focusNode → FocusNode?
An optional focus node to use as the focus node for this widget.
final
gradient → Gradient
The gradient to be applied to the background
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onLongPress → VoidCallback?
Called when the button is long-pressed.
final
onPressed → VoidCallback?
Called when the button is tapped or otherwise activated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ButtonStyle?
Customizes this button's appearance.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _ButtonStyleState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
defaultStyleOf(BuildContext context) → ButtonStyle
Returns a non-null ButtonStyle that's based primarily on the Theme's ThemeData.textTheme and ThemeData.colorScheme.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
themeStyleOf(BuildContext context) → ButtonStyle?
Returns the ButtonStyle that belongs to the button's component theme.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

allOrNull<T>(T? value) → WidgetStateProperty<T>?
Returns null if value is null, otherwise MaterialStateProperty.all<T>(value).
scaledPadding(EdgeInsetsGeometry geometry1x, EdgeInsetsGeometry geometry2x, EdgeInsetsGeometry geometry3x, double textScaleFactor) → EdgeInsetsGeometry
Returns an interpolated value based on the textScaleFactor parameter: