GradientCard class

Inheritance

Constructors

GradientCard({Key? key, Color? color, required Gradient gradient, Color? shadowColor, double? elevation, ShapeBorder? shape, bool borderOnForeground = true, EdgeInsets? margin, EdgeInsets padding = const EdgeInsets.all(8.0), Clip? clipBehavior, Widget? child, bool semanticContainer = true})
The elevation must be null or non-negative. The borderOnForeground must not be null.

Properties

borderOnForeground → bool
Whether to paint the shape border in front of the child.
finalinherited
child → Widget?
The widget below this widget in the tree.
finalinherited
clipBehavior → Clip?
The content will be clipped (or not) according to this option.
finalinherited
color → Color?
The card's background color.
finalinherited
elevation → double?
The z-coordinate at which to place this card. This controls the size of the shadow below the card.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
The empty space that surrounds the card.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticContainer → bool
Whether this widget represents a single semantic container, or if false a collection of individual semantic nodes.
finalinherited
shadowColor → Color?
The color to paint the shadow below the card.
finalinherited
shape → ShapeBorder?
The shape of the card's Material.
finalinherited
surfaceTintColor → Color?
The color used as an overlay on color to indicate elevation.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited