GradientCircularProgressIndicator class

A material design circular progress indicator, which spins to indicate that the application is busy.

A widget that shows progress along a circle. There are two kinds of circular progress indicators:

  • Determinate. Determinate progress indicators have a specific value at each point in time, and the value should increase monotonically from 0.0 to 1.0, at which time the indicator is complete. To create a determinate progress indicator, use a non-null value between 0.0 and 1.0.
  • Indeterminate. Indeterminate progress indicators do not have a specific value at each point in time and instead indicate that progress is being made without indicating how much progress remains. To create an indeterminate progress indicator, use a null value.

The indicator arc is displayed with valueGradient, an animated value. To specify a constant color use: AlwaysStoppedAnimation<Color>(color).

See also:

Inheritance

Constructors

GradientCircularProgressIndicator({Key? key, double? value, Color? backgroundColor, required Gradient valueGradient, double strokeWidth = 4.0, String? semanticsLabel, String? semanticsValue})
Creates a circular progress indicator.
const
GradientCircularProgressIndicator.adaptive({Key? key, double? value, Color? backgroundColor, required Gradient valueGradient, double strokeWidth = 4.0, String? semanticsLabel, String? semanticsValue})
Creates an adaptive progress indicator that is a CupertinoActivityIndicator in iOS and GradientCircularProgressIndicator in material theme/non-iOS.
const

Properties

backgroundColor → Color?
The progress indicator's background color.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The SemanticsProperties.label for this progress indicator.
finalinherited
semanticsValue → String?
The SemanticsProperties.value for this progress indicator.
finalinherited
strokeWidth → double
The width of the line used to draw the circle.
final
value → double?
If non-null, the value of this progress indicator.
finalinherited
valueGradient → Gradient
The progress indicator's color as an animated value.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _CircularProgressIndicatorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited