GradientProgressIndicator class abstract

A base class for material design progress indicators.

This widget cannot be instantiated directly. For a linear progress indicator, see LinearProgressIndicator. For a circular progress indicator, see GradientCircularProgressIndicator.

See also:

Inheritance
Implementers

Constructors

GradientProgressIndicator({Key? key, double? value, Color? backgroundColor, required Gradient valueGradient, String? semanticsLabel, String? semanticsValue})
Creates a progress indicator.
const

Properties

backgroundColor → Color?
The progress indicator's background color.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The SemanticsProperties.label for this progress indicator.
final
semanticsValue → String?
The SemanticsProperties.value for this progress indicator.
final
value → double?
If non-null, the value of this progress indicator.
final
valueGradient → Gradient
The progress indicator's color as an animated value.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited