GradientSelectableText class

Inheritance

Constructors

GradientSelectableText(String data, {required Gradient gradient, Key? key, FocusNode? focusNode, TextStyle style = const TextStyle(color: Colors.white), StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, double? textScaleFactor, bool showCursor = false, bool autofocus = false, int? minLines, int? maxLines, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool enableInteractiveSelection = true, TextSelectionControls? selectionControls, GestureTapCallback? onTap, ScrollPhysics? scrollPhysics, TextHeightBehavior? textHeightBehavior, TextWidthBasis? textWidthBasis, SelectionChangedCallback? onSelectionChanged})
const
GradientSelectableText.rich(TextSpan textSpan, {required Gradient gradient, Key? key, FocusNode? focusNode, TextStyle style = const TextStyle(color: Colors.white), StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, double? textScaleFactor, bool showCursor = false, bool autofocus = false, int? minLines, int? maxLines, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool enableInteractiveSelection = true, TextSelectionControls? selectionControls, GestureTapCallback? onTap, ScrollPhysics? scrollPhysics, TextHeightBehavior? textHeightBehavior, TextWidthBasis? textWidthBasis, SelectionChangedCallback? onSelectionChanged})
const

Properties

autofocus → bool
final
cursorColor → Color?
final
cursorHeight → double?
final
cursorRadius → Radius?
final
cursorWidth → double
final
data → String?
final
dragStartBehavior → DragStartBehavior
final
enableInteractiveSelection → bool
final
focusNode → FocusNode?
final
gradient → Gradient
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines → int?
final
minLines → int?
final
onSelectionChanged → SelectionChangedCallback?
final
onTap → GestureTapCallback?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics → ScrollPhysics?
final
selectionControls → TextSelectionControls?
final
selectionEnabled → bool
no setter
showCursor → bool
final
strutStyle → StrutStyle?
final
style → TextStyle
final
textAlign → TextAlign?
final
textDirection → TextDirection?
final
textHeightBehavior → TextHeightBehavior?
final
textScaleFactor → double?
final
textSpan → TextSpan?
final
textWidthBasis → TextWidthBasis?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited